@@ -31,9 +31,6 @@ def sibpath(filename):
 
 class Apache(object):
 
-    template = os.path.join(os.path.dirname(__file__), "apache.cfg")
-    ssltemplate = os.path.join(os.path.dirname(__file__), "apache-ssl.cfg")
-
     def __init__(self, buildout, name, options):
         self.name = name
         self.options = options
@@ -42,7 +39,7 @@ class Apache(object):
             default_template = "apache-ssl.cfg"
         else:
             default_template = "apache.cfg"
-        self.outputdir = os.path.join(self.buildout['buildout']['directory'], self.name)
+        self.outputdir = os.path.join(self.buildout['buildout']['parts-directory'], self.name)
         self.options.setdefault("template", sibpath(default_template))
         self.options.setdefault("passwdfile", os.path.join(self.outputdir, "passwd"))
         self.options.setdefault("configfile", os.path.join(self.outputdir, "apache.cfg"))
